@@ -4,7 +4,9 @@ from .general import default_print
 from .global_control import disable
 from .global_control import enable
 from .global_control import setup
+from .global_control import setup_for_ipython
 from .global_control import unload
+from .global_control import update
 from .logger import lk
 
-__version__ = '5.1.5'
+__version__ = '5.2.1'
